============
LyricsMaster
============


.. image:: https://img.shields.io/pypi/v/lyricsmaster.svg
        :target: https://pypi.python.org/pypi/lyricsmaster

.. image:: https://img.shields.io/travis/SekouD/lyricsmaster.svg
        :target: https://travis-ci.org/SekouD/lyricsmaster

.. image:: https://readthedocs.org/projects/lyricsmaster/badge/?version=latest
        :target: https://lyricsmaster.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/SekouD/lyricsmaster/shield.svg
     :target: https://pyup.io/repos/github/SekouD/lyricsmaster/
     :alt: Updates


LyricsMaster is a library for analyzing lyrics using various Machine Learning algorithms. It includes utilities for downloading lyrics from multiple lyrics providers.


* Free software: MIT license
* Documentation: https://lyricsmaster.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

